==> dokuwiki_0.0.20080505.orig.tar.gz: dokuwiki-2008-05-05/inc/lang/cs/lang.php <==
<?php
/**
 * Czech language file
 *
 * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
 * @author Bohumir Zamecnik <bohumir@zamecnik.org>
 * @author Tomas Valenta <t.valenta@sh.cvut.cz>
 * @author Zbynek Krivka <zbynek.krivka@seznam.cz>
 */
$lang['encoding']              = 'utf-8';
$lang['direction']             = 'ltr';
$lang['doublequoteopening']    = '„';
$lang['doublequoteclosing']    = '“';
$lang['singlequoteopening']    = '‚';
$lang['singlequoteclosing']    = '‘';
$lang['apostrophe']            = '\'';
$lang['btn_edit']              = 'Upravit stránku';
$lang['btn_source']            = 'Zdrojový kód stránky';
$lang['btn_show']              = 'Zobrazit stránku';
$lang['btn_create']            = 'Vytvořit stránku';
$lang['btn_search']            = 'Hledat';
$lang['btn_save']              = 'Uložit';
$lang['btn_preview']           = 'Náhled';
$lang['btn_top']               = 'Nahoru';
$lang['btn_newer']             = '<< novější';
$lang['btn_older']             = 'starší >>';
$lang['btn_revs']              = 'Starší verze';
$lang['btn_recent']            = 'Poslední úpravy';
$lang['btn_upload']            = 'Přiložit';
$lang['btn_cancel']            = 'Storno';
$lang['btn_index']             = 'Index';
$lang['btn_secedit']           = 'Upravit';
$lang['btn_login']             = 'Přihlásit se';
$lang['btn_logout']            = 'Odhlásit se';
$lang['btn_admin']             = 'Správa';
$lang['btn_update']            = 'Aktualizovat';
$lang['btn_delete']            = 'Vymazat';
$lang['btn_back']              = 'Zpět';
$lang['btn_backlink']          = 'Zpětné odkazy';
$lang['btn_backtomedia']       = 'Zpět do Výběru dokumentu';
$lang['btn_subscribe']         = 'Odebírat mailem změny stránky';
$lang['btn_unsubscribe']       = 'Neodebírat mailem změny stránky';
$lang['btn_subscribens']       = 'Odebírat mailem změny ve jmenném prostoru';
$lang['btn_unsubscribens']     = 'Neodebírat mailem změny ve jmenném prostoru';
$lang['btn_profile']           = 'Upravit profil';
$lang['btn_reset']             = 'Reset';
$lang['btn_resendpwd']         = 'Zaslat nové heslo';
$lang['btn_draft']             = 'Upravit koncept';
$lang['btn_recover']           = 'Obnovit koncept';
$lang['btn_draftdel']          = 'Vymazat koncept';
$lang['loggedinas']            = 'Přihlášen(a) jako';
$lang['user']                  = 'Uživatelské jméno';
$lang['pass']                  = 'Heslo';
$lang['newpass']               = 'Nové heslo';
$lang['oldpass']               = 'Současné heslo';
$lang['passchk']               = 'ještě jednou';
$lang['remember']              = 'Přihlásit se nastálo';
$lang['fullname']              = 'Celé jméno';
$lang['email']                 = 'E-mail';
$lang['register']              = 'Registrovat';
$lang['profile']               = 'Uživatelský profil';
$lang['badlogin']              = 'Zadané uživatelské jméno a heslo není správně.';
$lang['minoredit']             = 'Drobné změny';
$lang['draftdate']             = 'Koncept automaticky uložen v';
$lang['regmissing']            = 'Musíte vyplnit všechny údaje.';
$lang['reguexists']            = 'Uživatel se stejným jménem už je zaregistrován.';
$lang['regsuccess']            = 'Uživatelský účet byl vytvořen a heslo zasláno mailem.';
$lang['regsuccess2']           = 'Uživatelský účet byl vytvořen.';
$lang['regmailfail']           = 'Zdá se, že nastala chyba při posílání mailu s heslem. Zkuste kontaktovat správce.';
$lang['regbadmail']            = 'Zadaná mailová adresa není platná. Pokud si myslíte, že to je špatně, zkuste kontaktovat správce.';
$lang['regbadpass']            = 'Heslo nebylo zadáno dvakrát stejně, zkuste to prosím znovu.';
$lang['regpwmail']             = 'Vaše heslo do systému DokuWiki';
$lang['reghere']               = 'Nemáte uživatelský účet? Zřiďte si ho';
$lang['profna']                = 'Tato wiki neumožňuje změnu profilu';
$lang['profnochange']          = 'Žádné změny nebyly provedeny.';
$lang['profnoempty']           = 'Nelze zadat prázdné jméno nebo mailová adresa.';
$lang['profchanged']           = 'Uživatelský profil změněn.';
$lang['pwdforget']             = 'Zapomněli jste heslo? Nechte si zaslat nové';
$lang['resendna']              = 'Tato wiki neumožňuje zasílání nových hesel.';
$lang['resendpwd']             = 'Odeslat nové heslo pro uživatele';
$lang['resendpwdmissing']      = 'Musíte vyplnit všechny položky.';
$lang['resendpwdnouser']       = 'Bohužel takový uživatel v systému není.';
$lang['resendpwdbadauth']      = 'Autorizační kód není platný. Zadali jste opravdu celý odkaz na potvrzovací stránku?';
$lang['resendpwdconfirm']      = 'Odkaz na potvrzovací stránku byl odeslán mailem.';
$lang['resendpwdsuccess']      = 'Vaše nové heslo bylo odesláno emailem.';
$lang['txt_upload']            = 'Vyberte soubor jako přílohu';
$lang['txt_filename']          = 'Wiki jméno (volitelné)';
$lang['txt_overwrt']           = 'Přepsat existující soubor';
$lang['lockedby']              = 'Právě zamknuto:';
$lang['lockexpire']            = 'Zámek vyprší:';
$lang['willexpire']            = 'Váš zámek pro editaci za chvíli vyprší.\nAbyste předešli konfliktům, stiskněte tlačítko Náhled a zámek se prodlouží.';
$lang['notsavedyet']           = 'Jsou tu neuložené změny, které budou ztraceny.\nChcete opravdu pokračovat?';
$lang['rssfailed']             = 'Nastala chyba při vytváření tohoto RSS: ';
$lang['nothingfound']          = 'Nic nenalezeno.';
$lang['mediaselect']           = 'Výběr dokumentu';
$lang['fileupload']            = 'Nahrávání dokumentu';
$lang['uploadsucc']            = 'Přenos proběhl v pořádku';
$lang['uploadfail']            = 'Chyba při nahrávání. Možná kvůli špatně nastaveným právům?';
$lang['uploadwrong']           = 'Přiložení souboru s takovouto příponou není dovoleno.';
$lang['uploadexist']           = 'Soubor už existuje, necháme ho být.';
$lang['uploadbadcontent']      = 'Obsah přiloženého dokumentu %s neodpovídá jeho příponě.';
$lang['uploadspam']            = 'Přiložený dokument byl odmítnut, je na spamovém blacklistu.';
$lang['uploadxss']             = 'Přiložený dokument byl odmítnut. Zdá se, že obsahuje škodlivé věci.';
$lang['deletesucc']            = 'Soubor "%s" byl vymazán.';
$lang['deletefail']            = 'Soubor "%s" nelze vymazat - zkontrolujte oprávnění.';
$lang['mediainuse']            = 'Soubor "%s" nebyl vymazán - stále se používá.';
$lang['namespaces']            = 'Jmenné prostory';
$lang['mediafiles']            = 'Dostupné soubory';
$lang['js']['keepopen']        = 'Po vybrání souboru nechat okno otevřené';
$lang['js']['hidedetails']     = 'Skrýt detaily';
$lang['mediausage']            = 'K odkázání se na tento soubor použijte následující syntax:';
$lang['mediaview']             = 'Zobrazit původní soubor';
$lang['mediaroot']             = 'root';
$lang['mediaupload']           = 'Přiložit soubor do aktuálního jmenného prostoru. K vytvoření nových jmenných prostorů, přidejte jejich názvy na začátek wiki jména (oddělte dvojtečkou).';
$lang['mediaextchange']        = 'Přípona souboru byla změněna z .%s na .%s!';
$lang['reference']             = 'Odkazy na';
$lang['ref_inuse']             = 'Soubor nelze vymazat, jelikož ho využívají následující stránky:';
$lang['ref_hidden']            = 'Některé odkazy jsou na stránkách, kam nemáte právo přístupu';
$lang['hits']                  = '- počet výskytů';
$lang['quickhits']             = 'Odpovídající stránky';
$lang['toc']                   = 'Obsah';
$lang['current']               = 'aktuální';
$lang['yours']                 = 'Vaše verze';
$lang['diff']                  = 'zobrazit rozdíly vůči aktuální verzi';
$lang['diff2']                 = 'zobrazit rozdíly mezi vybranými verzemi';
$lang['line']                  = 'Řádek';
$lang['breadcrumb']            = 'Historie';
$lang['youarehere']            = 'Umístění';
$lang['lastmod']               = 'Poslední úprava';
$lang['by']                    = 'autor:';
$lang['deleted']               = 'odstraněno';
$lang['created']               = 'vytvořeno';
$lang['restored']              = 'stará verze byla obnovena';
$lang['external_edit']         = 'upraveno mimo DokuWiki';
$lang['summary']               = 'Komentář k úpravám';
$lang['mail_newpage']          = 'nová stránka:';
$lang['mail_changed']          = 'změna stránky:';
$lang['mail_new_user']         = 'nový uživatel:';
$lang['mail_upload']           = 'nahraný dokument:';
$lang['nosmblinks']            = 'Odkazování na sdílené prostředky Windows funguje jen v Internet Exploreru.\nPřesto tento odkaz můžete zkopírovat a vložit jinde.';
$lang['qb_alert']              = 'Vložte prosím text, který chcete formátovat.\nBude pak přidán na konec dokumentu.';
$lang['qb_bold']               = 'Tučně';
$lang['qb_italic']             = 'Kurzíva';
$lang['qb_underl']             = 'Podtržení';
$lang['qb_code']               = 'Neformátovat (zdrojový kód)';
$lang['qb_strike']             = 'Přeškrtnutý text';
$lang['qb_h1']                 = 'Nadpis 1. úrovně';
$lang['qb_h2']                 = 'Nadpis 2. úrovně';
$lang['qb_h3']                 = 'Nadpis 3. úrovně';
$lang['qb_h4']                 = 'Nadpis 4. úrovně';
$lang['qb_h5']                 = 'Nadpis 5. úrovně';
$lang['qb_link']               = 'Interní odkaz';
$lang['qb_extlink']            = 'Externí odkaz';
$lang['qb_hr']                 = 'Vodorovná čára';
$lang['qb_ol']                 = 'Číslovaný seznam';
$lang['qb_ul']                 = 'Nečíslovaný seznam';
$lang['qb_media']              = 'Vložit obrázky nebo jiné soubory';
$lang['qb_sig']                = 'Vložit podpis';
$lang['qb_smileys']            = 'Emotikony';
$lang['qb_chars']              = 'Speciální znaky';
$lang['del_confirm']           = 'Vymazat tuto položku?';
$lang['admin_register']        = 'Přidat nového uživatele';
$lang['metaedit']              = 'Upravit Metadata';
$lang['metasaveerr']           = 'Chyba při zápisu metadat';
$lang['metasaveok']            = 'Metadata uložena';
$lang['img_backto']            = 'Zpět na';
$lang['img_title']             = 'Titulek';
$lang['img_caption']           = 'Popis';
$lang['img_date']              = 'Datum';
$lang['img_fname']             = 'Jméno souboru';
$lang['img_fsize']             = 'Velikost';
$lang['img_artist']            = 'Autor fotografie';
$lang['img_copyr']             = 'Copyright';
$lang['img_format']            = 'Formát';
$lang['img_camera']            = 'Typ fotoaparátu';
$lang['img_keywords']          = 'Klíčová slova';
$lang['subscribe_success']     = 'Uživatel %s je nyní přihlášen k odběru změn ve stránce %s';
$lang['subscribe_error']       = 'Chyba při zařazování uživatele %s do seznamu pro odběr změn ve stránce %s';
$lang['subscribe_noaddress']   = 'K vašemu uživatelskému profilu chybí mailová adresa, takže vás nelze zařadit do seznamu pro odběr změn';
$lang['unsubscribe_success']   = 'Uživatel %s byl odebrán ze seznamu pro odběr změn ve stránce %s';
$lang['unsubscribe_error']     = 'Chyba při odstraňování uživatele %s ze seznamu pro odběru změn ve stránce %s';
$lang['authmodfailed']         = 'Autentizace uživatelů je špatně nastavena. Informujte prosím správce této wiki.';
$lang['authtempfail']          = 'Autentizace uživatelů je dočasně nedostupná. Pokud tento problém přetrvává, informujte prosím správce této wiki.';
$lang['i_chooselang']          = 'Vyberte si jazyk';
$lang['i_installer']           = 'Instalace DokuWiki';
$lang['i_wikiname']            = 'Název wiki';
$lang['i_enableacl']           = 'Zapnout ACL (doporučeno)';
$lang['i_superuser']           = 'Správce';
$lang['i_problems']            = 'Instalátor narazil na níže popsané problémy. Nelze pokračovat v instalaci, dokud je neopravíte.';
$lang['i_modified']            = 'Instalátor bude z bezpečnostních důvodů pracovat pouze s čistou a ještě neupravenou instalací DokuWiki. Buď znovu rozbalte souboru z instalačního balíčku nebo se zkuste poradit s <a href="http://wiki.splitbrain.org/wiki:install">instrukcemi pro instalci DokuWiki</a>.';
$lang['i_funcna']              = 'PHP funkce <code>%s</code> není dostupná. Váš webhosting ji možná z nějakého důvodu vypnul.';
$lang['i_phpver']              = 'Verze vaší instalace PHP <code>%s</code> je nižší než požadovaná <code>%s</code>. Budete muset aktualizovat svou instalaci PHP.';
$lang['i_permfail']            = 'DokuWiki nemůže zapisovat do <code>%s</code>. Budete muset opravit práva k tomuto adresáři.';
$lang['i_confexists']          = '<code>%s</code> již existuje';
$lang['i_writeerr']            = 'Nelze vytvořit <code>%s</code>. Budete muset zkontrolovat práva k souborům či adresářům a vytvořit tento soubor ručně.';
$lang['i_badhash']             = 'soubor dokuwiki.php (hash=<code>%s</code>) nebyl rozpoznán nebo byl upraven';
$lang['i_badval']              = '<code>%s</code> - neplatná nebo prázdná hodnota';
$lang['i_success']             = 'Konfigurace byla úspěšně dokončena. Nyní můžete smazat soubor install.php. Pokračujte do <a href="doku.php">své nové DokuWiki</a>.';
$lang['i_failure']             = 'Vyskytly se nějaké chyby při zápisu do konfiguračních souborů. Budete je nejspíš muset upravit ručně před použitím <a href="doku.php">své nové DokuWiki</a>.';
$lang['i_policy']              = 'Úvodní politika ACL';
$lang['i_pol0']                = 'Otevřená wiki (čtení, zápis a upload pro všechny)';
$lang['i_pol1']                = 'Veřejná wiki (čtení pro všechny, zápis a upload pro registrované uživatele)';
$lang['i_pol2']                = 'Uzavřená wiki (čtení, zápis a upload pouze pro registrované uživatele)';
$lang['i_retry']               = 'Zkusit znovu';

==> dokuwiki_0.0.20090214b.orig.tar.gz: dokuwiki-2009-02-14/inc/lang/cs/lang.php <==
<?php
/**
 * Czech language file
 *
 * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
 * @author Bohumir Zamecnik <bohumir@zamecnik.org>
 * @author Tomas Valenta <t.valenta@sh.cvut.cz>
 * @author Zbynek Krivka <zbynek.krivka@seznam.cz>
 */
$lang['encoding']              = 'utf-8';
$lang['direction']             = 'ltr';
$lang['doublequoteopening']    = '„';
$lang['doublequoteclosing']    = '“';
$lang['singlequoteopening']    = '‚';
$lang['singlequoteclosing']    = '‘';
$lang['apostrophe']            = '\'';
$lang['btn_edit']              = 'Upravit stránku';
$lang['btn_source']            = 'Zdrojový kód stránky';
$lang['btn_show']              = 'Zobrazit stránku';
$lang['btn_create']            = 'Vytvořit stránku';
$lang['btn_search']            = 'Hledat';
$lang['btn_save']              = 'Uložit';
$lang['btn_preview']           = 'Náhled';
$lang['btn_top']               = 'Nahoru';
$lang['btn_newer']             = '<< novější';
$lang['btn_older']             = 'starší >>';
$lang['btn_revs']              = 'Starší verze';
$lang['btn_recent']            = 'Poslední úpravy';
$lang['btn_upload']            = 'Načíst';
$lang['btn_cancel']            = 'Storno';
$lang['btn_index']             = 'Index';
$lang['btn_secedit']           = 'Upravit';
$lang['btn_login']             = 'Přihlásit se';
$lang['btn_logout']            = 'Odhlásit se';
$lang['btn_admin']             = 'Správa';
$lang['btn_update']            = 'Aktualizovat';
$lang['btn_delete']            = 'Vymazat';
$lang['btn_back']              = 'Zpět';
$lang['btn_backlink']          = 'Zpětné odkazy';
$lang['btn_backtomedia']       = 'Zpět do Výběru dokumentu';
$lang['btn_subscribe']         = 'Odebírat mailem změny stránky';
$lang['btn_unsubscribe']       = 'Neodebírat mailem změny stránky';
$lang['btn_subscribens']       = 'Odebírat mailem změny ve jmenném prostoru';
$lang['btn_unsubscribens']     = 'Neodebírat mailem změny ve jmenném prostoru';
$lang['btn_profile']           = 'Upravit profil';
$lang['btn_reset']             = 'Reset';
$lang['btn_resendpwd']         = 'Zaslat nové heslo';
$lang['btn_draft']             = 'Upravit koncept';
$lang['btn_recover']           = 'Obnovit koncept';
$lang['btn_draftdel']          = 'Vymazat koncept';
$lang['loggedinas']            = 'Přihlášen(a) jako';
$lang['user']                  = 'Uživatelské jméno';
$lang['pass']                  = 'Heslo';
$lang['newpass']               = 'Nové heslo';
$lang['oldpass']               = 'Současné heslo';
$lang['passchk']               = 'ještě jednou';
$lang['remember']              = 'Přihlásit se nastálo';
$lang['fullname']              = 'Celé jméno';
$lang['email']                 = 'E-mail';
$lang['register']              = 'Registrovat';
$lang['profile']               = 'Uživatelský profil';
$lang['badlogin']              = 'Zadané uživatelské jméno a heslo není správně.';
$lang['minoredit']             = 'Drobné změny';
$lang['draftdate']             = 'Koncept automaticky uložen v';
$lang['nosecedit']             = 'Stránka byla v mezičase změněna. Informace o sekci již nebylo platné, byla načtena celá stránka.';
$lang['regmissing']            = 'Musíte vyplnit všechny údaje.';
$lang['reguexists']            = 'Uživatel se stejným jménem už je zaregistrován.';
$lang['regsuccess']            = 'Uživatelský účet byl vytvořen a heslo zasláno mailem.';
$lang['regsuccess2']           = 'Uživatelský účet byl vytvořen.';
$lang['regmailfail']           = 'Zdá se, že nastala chyba při posílání mailu s heslem. Zkuste kontaktovat správce.';
$lang['regbadmail']            = 'Zadaná mailová adresa není platná. Pokud si myslíte, že to je špatně, zkuste kontaktovat správce.';
$lang['regbadpass']            = 'Heslo nebylo zadáno dvakrát stejně, zkuste to prosím znovu.';
$lang['regpwmail']             = 'Vaše heslo do systému DokuWiki';
$lang['reghere']               = 'Nemáte uživatelský účet? Zřiďte si ho';
$lang['profna']                = 'Tato wiki neumožňuje změnu profilu';
$lang['profnochange']          = 'Žádné změny nebyly provedeny.';
$lang['profnoempty']           = 'Nelze zadat prázdné jméno nebo mailová adresa.';
$lang['profchanged']           = 'Uživatelský profil změněn.';
$lang['pwdforget']             = 'Zapomněli jste heslo? Nechte si zaslat nové';
$lang['resendna']              = 'Tato wiki neumožňuje zasílání nových hesel.';
$lang['resendpwd']             = 'Odeslat nové heslo pro uživatele';
$lang['resendpwdmissing']      = 'Musíte vyplnit všechny položky.';
$lang['resendpwdnouser']       = 'Bohužel takový uživatel v systému není.';
$lang['resendpwdbadauth']      = 'Autorizační kód není platný. Zadali jste opravdu celý odkaz na potvrzovací stránku?';
$lang['resendpwdconfirm']      = 'Odkaz na potvrzovací stránku byl odeslán mailem.';
$lang['resendpwdsuccess']      = 'Vaše nové heslo bylo odesláno emailem.';
$lang['license']               = 'Kromě míst, kde je explicitně uvedeno jinak, je obsah této wiki licencován pod následující licencí:';
$lang['licenseok']             = 'Poznámka: Tím, že editujete tuto stránku, souhlasíte, aby váš obsah byl licencován pod následující licencí:';
$lang['txt_upload']            = 'Vyberte soubor jako přílohu';
$lang['txt_filename']          = 'Wiki jméno (volitelné)';
$lang['txt_overwrt']           = 'Přepsat existující soubor';
$lang['lockedby']              = 'Právě zamknuto:';
$lang['lockexpire']            = 'Zámek vyprší:';
$lang['willexpire']            = 'Váš zámek pro editaci za chvíli vyprší.\nAbyste předešli konfliktům, stiskněte tlačítko Náhled a zámek se prodlouží.';
$lang['notsavedyet']           = 'Jsou tu neuložené změny, které budou ztraceny.\nChcete opravdu pokračovat?';
$lang['rssfailed']             = 'Nastala chyba při vytváření tohoto RSS: ';
$lang['nothingfound']          = 'Nic nenalezeno.';
$lang['mediaselect']           = 'Výběr dokumentu';
$lang['fileupload']            = 'Načtení dokumentu';
$lang['uploadsucc']            = 'Přenos proběhl v pořádku';
$lang['uploadfail']            = 'Chyba při načítání. Možná kvůli špatně nastaveným právům?';
$lang['uploadwrong']           = 'Načtení souboru s takovouto příponou není dovoleno.';
$lang['uploadexist']           = 'Soubor už existuje, necháme ho být.';
$lang['uploadbadcontent']      = 'Obsah načteného dokumentu %s neodpovídá jeho příponě.';
$lang['uploadspam']            = 'Načtený dokument byl odmítnut, je na spamovém blacklistu.';
$lang['uploadxss']             = 'Načtený dokument byl odmítnut. Zdá se, že obsahuje škodlivé věci.';
$lang['uploadsize']            = 'Nahraný soubor byl příliš velký (max. %s)';
$lang['deletesucc']            = 'Soubor "%s" byl vymazán.';
$lang['deletefail']            = 'Soubor "%s" nelze vymazat - zkontrolujte oprávnění.';
$lang['mediainuse']            = 'Soubor "%s" nebyl vymazán - stále se používá.';
$lang['namespaces']            = 'Jmenné prostory';
$lang['mediafiles']            = 'Dostupné soubory';
$lang['js']['keepopen']        = 'Po vybrání souboru nechat okno otevřené';
$lang['js']['hidedetails']     = 'Skrýt detaily';
$lang['js']['nosmblinks']      = 'Odkazování na sdílené prostředky Windows funguje jen v Internet Exploreru.
Přesto tento odkaz můžete zkopírovat a vložit jinde.';
$lang['js']['mu_btn']          = 'Načíst více souborů najednou';
$lang['mediausage']            = 'K odkázání se na tento soubor použijte následující syntax:';
$lang['mediaview']             = 'Zobrazit původní soubor';
$lang['mediaroot']             = 'root';
$lang['mediaupload']           = 'Načíst soubor do aktuálního jmenného prostoru. K vytvoření nových jmenných prostorů, přidejte jejich názvy na začátek wiki jména (oddělte dvojtečkou).';
$lang['mediaextchange']        = 'Přípona souboru byla změněna z .%s na .%s!';
$lang['reference']             = 'Odkazy na';
$lang['ref_inuse']             = 'Soubor nelze vymazat, jelikož ho využívají následující stránky:';
$lang['ref_hidden']            = 'Některé odkazy jsou na stránkách, kam nemáte právo přístupu';
$lang['hits']                  = '- počet výskytů';
$lang['quickhits']             = 'Odpovídající stránky';
$lang['toc']                   = 'Obsah';
$lang['current']               = 'aktuální';
$lang['yours']                 = 'Vaše verze';
$lang['diff']                  = 'zobrazit rozdíly vůči aktuální verzi';
$lang['diff2']                 = 'zobrazit rozdíly mezi vybranými verzemi';
$lang['line']                  = 'Řádek';
$lang['breadcrumb']            = 'Historie';
$lang['youarehere']            = 'Umístění';
$lang['lastmod']               = 'Poslední úprava';
$lang['by']                    = 'autor:';
$lang['deleted']               = 'odstraněno';
$lang['created']               = 'vytvořeno';
$lang['restored']              = 'stará verze byla obnovena';
$lang['external_edit']         = 'upraveno mimo DokuWiki';
$lang['summary']               = 'Komentář k úpravám';
$lang['noflash']               = 'Pro přehrání obsahu potřebujete <a href="http://www.adobe.com/products/flashplayer/">Adobe Flash Plugin</a>.';
$lang['mail_newpage']          = 'nová stránka:';
$lang['mail_changed']          = 'změna stránky:';
$lang['mail_new_user']         = 'nový uživatel:';
$lang['mail_upload']           = 'načtený dokument:';
$lang['qb_alert']              = 'Vložte prosím text, který chcete formátovat.\nBude pak přidán na konec dokumentu.';
$lang['qb_bold']               = 'Tučně';
$lang['qb_italic']             = 'Kurzíva';
$lang['qb_underl']             = 'Podtržení';
$lang['qb_code']               = 'Neformátovat (zdrojový kód)';
$lang['qb_strike']             = 'Přeškrtnutý text';
$lang['qb_h1']                 = 'Nadpis 1. úrovně';
$lang['qb_h2']                 = 'Nadpis 2. úrovně';
$lang['qb_h3']                 = 'Nadpis 3. úrovně';
$lang['qb_h4']                 = 'Nadpis 4. úrovně';
$lang['qb_h5']                 = 'Nadpis 5. úrovně';
$lang['qb_link']               = 'Interní odkaz';
$lang['qb_extlink']            = 'Externí odkaz';
$lang['qb_hr']                 = 'Vodorovná čára';
$lang['qb_ol']                 = 'Číslovaný seznam';
$lang['qb_ul']                 = 'Nečíslovaný seznam';
$lang['qb_media']              = 'Vložit obrázky nebo jiné soubory';
$lang['qb_sig']                = 'Vložit podpis';
$lang['qb_smileys']            = 'Emotikony';
$lang['qb_chars']              = 'Speciální znaky';
$lang['del_confirm']           = 'Vymazat tuto položku?';
$lang['admin_register']        = 'Přidat nového uživatele';
$lang['metaedit']              = 'Upravit Metadata';
$lang['metasaveerr']           = 'Chyba při zápisu metadat';
$lang['metasaveok']            = 'Metadata uložena';
$lang['img_backto']            = 'Zpět na';
$lang['img_title']             = 'Titulek';
$lang['img_caption']           = 'Popis';
$lang['img_date']              = 'Datum';
$lang['img_fname']             = 'Jméno souboru';
$lang['img_fsize']             = 'Velikost';
$lang['img_artist']            = 'Autor fotografie';
$lang['img_copyr']             = 'Copyright';
$lang['img_format']            = 'Formát';
$lang['img_camera']            = 'Typ fotoaparátu';
$lang['img_keywords']          = 'Klíčová slova';
$lang['subscribe_success']     = 'Uživatel %s je nyní přihlášen k odběru změn ve stránce %s';
$lang['subscribe_error']       = 'Chyba při zařazování uživatele %s do seznamu pro odběr změn ve stránce %s';
$lang['subscribe_noaddress']   = 'K vašemu uživatelskému profilu chybí mailová adresa, takže vás nelze zařadit do seznamu pro odběr změn';
$lang['unsubscribe_success']   = 'Uživatel %s byl odebrán ze seznamu pro odběr změn ve stránce %s';
$lang['unsubscribe_error']     = 'Chyba při odstraňování uživatele %s ze seznamu pro odběru změn ve stránce %s';
$lang['authmodfailed']         = 'Autentizace uživatelů je špatně nastavena. Informujte prosím správce této wiki.';
$lang['authtempfail']          = 'Autentizace uživatelů je dočasně nedostupná. Pokud tento problém přetrvává, informujte prosím správce této wiki.';
$lang['i_chooselang']          = 'Vyberte si jazyk';
$lang['i_installer']           = 'Instalace DokuWiki';
$lang['i_wikiname']            = 'Název wiki';
$lang['i_enableacl']           = 'Zapnout ACL (doporučeno)';
$lang['i_superuser']           = 'Správce';
$lang['i_problems']            = 'Instalátor narazil na níže popsané problémy. Nelze pokračovat v instalaci, dokud je neopravíte.';
$lang['i_modified']            = 'Instalátor bude z bezpečnostních důvodů pracovat pouze s čistou a ještě neupravenou instalací DokuWiki. Buď znovu rozbalte souboru z instalačního balíčku nebo se zkuste poradit s <a href="http://dokuwiki.org/install">instrukcemi pro instalci DokuWiki</a>.';
$lang['i_funcna']              = 'PHP funkce <code>%s</code> není dostupná. Váš webhosting ji možná z nějakého důvodu vypnul.';
$lang['i_phpver']              = 'Verze vaší instalace PHP <code>%s</code> je nižší než požadovaná <code>%s</code>. Budete muset aktualizovat svou instalaci PHP.';
$lang['i_permfail']            = 'DokuWiki nemůže zapisovat do <code>%s</code>. Budete muset opravit práva k tomuto adresáři.';
$lang['i_confexists']          = '<code>%s</code> již existuje';
$lang['i_writeerr']            = 'Nelze vytvořit <code>%s</code>. Budete muset zkontrolovat práva k souborům či adresářům a vytvořit tento soubor ručně.';
$lang['i_badhash']             = 'soubor dokuwiki.php (hash=<code>%s</code>) nebyl rozpoznán nebo byl upraven';
$lang['i_badval']              = '<code>%s</code> - neplatná nebo prázdná hodnota';
$lang['i_success']             = 'Konfigurace byla úspěšně dokončena. Nyní můžete smazat soubor install.php. Pokračujte do <a href="doku.php">své nové DokuWiki</a>.';
$lang['i_failure']             = 'Vyskytly se nějaké chyby při zápisu do konfiguračních souborů. Budete je nejspíš muset upravit ručně před použitím <a href="doku.php">své nové DokuWiki</a>.';
$lang['i_policy']              = 'Úvodní politika ACL';
$lang['i_pol0']                = 'Otevřená wiki (čtení, zápis a upload pro všechny)';
$lang['i_pol1']                = 'Veřejná wiki (čtení pro všechny, zápis a upload pro registrované uživatele)';
$lang['i_pol2']                = 'Uzavřená wiki (čtení, zápis a upload pouze pro registrované uživatele)';
$lang['i_retry']               = 'Zkusit znovu';
$lang['mu_intro']              = 'Zde můžete načíst více souborů najednou. Pro přidání souborů do fronty stiskněte tlačítko "Procházet". Až budete hotovi, stiskněte "Načíst".';
$lang['mu_gridname']           = 'Název souboru';
$lang['mu_gridsize']           = 'Velikost';
$lang['mu_gridstat']           = 'Stav';
$lang['mu_namespace']          = 'Jmenný prostor';
$lang['mu_browse']             = 'Procházet';
$lang['mu_toobig']             = 'příliš velké';
$lang['mu_ready']              = 'připraveno k načtení';
$lang['mu_done']               = 'hotovo';
$lang['mu_fail']               = 'selhalo';
$lang['mu_authfail']           = 'vypršla session';
$lang['mu_progress']           = '@PCT@% načten';
$lang['mu_filetypes']          = 'Povolené typy souborů';
$lang['recent_global']         = 'Právě si prohlížíte změny ve jmenném prostoru <b>%s</b>. Také si můžete <a href="%s">zobrazit změny v celé wiki</a>.';
